    import quickfix
    import quickfix42

    message = quickfix42.MarketDataSnapshotFullRefresh()
    group = quickfix42.MarketDataSnapshotFullRefresh().NoMDEntries()

    group.setField(quickfix.MDEntryType('0'))
    group.setField(quickfix.MDEntryPx(12.32))
    group.setField(quickfix.MDEntrySize(100))
    group.setField(quickfix.OrderID("ORDERID"))
    message.addGroup( group )

    group.setField(quickfix.MDEntryType('1'))
    group.setField(quickfix.MDEntryPx(12.32))
    group.setField(quickfix.MDEntrySize(100))
    group.setField(quickfix.OrderID("ORDERID"))
    message.addGroup( group )